/*
     This file is part of GNUnet
     (C) 2005, 2006, 2010 Christian Grothoff (and other contributing authors)

     GNUnet is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2, or (at your
     option) any later version.

     GNUnet is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with GNUnet; see the file COPYING.  If not, write to the
     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
*/

/**
 * @file src/fs/gnunet-fs-gtk-anonymtiy_spin_buttons.c
 * @author Christian Grothoff
 *
 * This file contains callbacks to turn spin buttons red when the
 * value reaches zero.
 */
#include "gnunet-fs-gtk-common.h"
#include <gdk/gdk.h>

/**
 * Spin button is changed, update its colour.
 */
void
GNUNET_GTK_anonymity_spin_button_value_changed_cb (GtkWidget * w, gpointer data)
{
#ifdef GdkRBGA
  GtkSpinButton *spin;
  gint val;
  GdkRGBA bcolor;
  GdkRGBA fcolor;

  spin = GTK_SPIN_BUTTON (w);
  if (spin == NULL)
  {
    GNUNET_break (0);
    return;
  }
  val = gtk_spin_button_get_value_as_int (spin);
  if (val == 0)
  {
    if ((TRUE == gdk_rgba_parse (&bcolor, "red")) &&
        (TRUE == gdk_rgba_parse (&fcolor, "black")))
    {
      gtk_widget_override_background_color (w, GTK_STATE_NORMAL, &bcolor);
      gtk_widget_override_color (w, GTK_STATE_NORMAL, &fcolor);
    }
    else
    {
      GNUNET_break (0);
    }
  }
  else
  {
    gtk_widget_override_background_color (w, GTK_STATE_NORMAL, NULL);
    gtk_widget_override_color (w, GTK_STATE_NORMAL, NULL);
  }
#endif
}


/* end of gnunet-fs-gtk-anonymtiy_spin_buttons.c */
